# Vallaris library
A package to made for support Vallaris Maps

Now supported Pythont >= 3.6

## How to use <br/>
1 Install python >= 3.6 <br/>
2 Install library vallaris ==> pip3 install vallaris<br/>
3 Create Use On Vallaris Maps at https://vallarismaps.com/management/signin<br/>
4 Download source code at https://repo.i-bitz.co.th/vallaris_example/vallaris-python

## Select a file from the code folder.  for data management in Vallaris Maps <br/> 
- 1 collectionCreate.py  ==> for create Collection <br/>
- 2 collectionUpdate.py ==> for update Collection <br/>
- 3 collectionDelete.py ==> for delete Collection <br/>
- 4 featuresCreate.py ==> for create data in Collection <br/>
- 5 featuresUpdate.py ==> for update data in Collection <br/>
- 6 featuresDelete.py ==> for delete data in Collection <br/>
- 7 featuresExport.py ==> for download data in Collection <br/>
- 8 vectortileCreate.py ==> for Vector Tile  <br/>

## Select a file from the code folder.  for create Module processes in Vallaris Maps <br/> 
- 1 perform.py ==> for write code python <br/>
- 2 mockProcess.py ==> for json test for use processes <br/>